(how-tos)=
# How-to guides

These guides show you how to complete tasks with napari. They assume you have
already installed **napari**, know how to launch the viewer, and are familiar
with its layout. For help with installation see our
[installation tutorial](../tutorials/fundamentals/installation). For help
getting started with the viewer see our
[Getting started guide](../tutorials/fundamentals/getting_started). For
help understanding the organisation of the viewer, including things like the
layers list, the layer properties widgets, the layer control panels, and the
dimension sliders see our [napari viewer](../tutorials/fundamentals/viewer)
tutorial.

- [Using layers](layers/index): Learn about how to use the layers currently
supported by napari.
- [Hooking up your own events](./connecting_events): Learn about the event loop
and how to use it to interact with napari.
- [napari + ImageJ how-to guide](./napari_imageJ): Learn about how to use napari
and ImageJ simultaneously.
- [napari in Docker](./docker): Learn about using napari in docker.
- [Performance monitoring](./perfmon): Learn about how to monitor napari
performance and diagnose potential problems.
- [napari headless](./headless): Tips on how to run napari headlessly.
